Crate dioxus_shareables
source · [−]Expand description
Crate dioxus-shareables
This crate provides abstractions for global resource sharing in
dioxus similar to fermi, but with a slightly different data
model, and some extensions for shared structures.
Re-exports
Modules
Macros
Create a struct definition for a global.
Structs
Marker for an access to shared data which is used for reading.
Marker for an access to shared data which is used for writing but not reading.
Traits
A type flag for shared pointers.