pub struct Shared<T: 'static, B: 'static> {
    pub id: Option<usize>,
    /* private fields */
}
A hook to a shared_value.

This is generally created by calling use_rw or use_w on a shareable!, or by calling ListEntry::use_rw or ListEntry::use_w.

Fields

id: Option<usize>

Implementations

Initialize the hook in scope cx.

The shared value will be initialized with f() if it hasn’t been created yet.

NOTE: this method should generally not be used directly; instead, shared values are usually created with shareable!.

Obtain a write pointer to the shared value and register the change.

This will mark all components which hold a RW link to the value as needing update.

Obtain a write pointer to the shared value but do not register the change.

This will not notify consumers of the change to the value.

Mark the components which hold a RW link to the value as needing update.

Set the shared value.

This marks compoments which hold a RW link to the value as needing update if and only if the value has changed.

Set the shared value to f(&x) where x is the current value.

This marks components which hold a RW link to the value as needing update if and only if the value has changed.

Get the value of the shared data.