Struct dioxus_shareables::RW
source · [−]pub struct RW;Expand description
Marker for an access to shared data which is used for reading.
Components which hold a RW handle are marked as needing update whenever that handle is
written to.