Struct dioxus_shareables::W
source · [−]pub struct W;Expand description
Marker for an access to shared data which is used for writing but not reading.
The primary promise for such an access is that it does not effect component display.