Crate dioxus-shareable

This crate provides abstractions for global resource sharing in Dioxus similar to, fermi, but with a slightly different data model, and some extensions for shared structures.

Re-exports

pub use shared::Shared;
pub use list::List;
pub use list::ListEntry;

Modules

mod list - lists of shared values.

Module shared - Shared values.

Macros

Declare a global variable for use as Shared hook.

Create a struct definition for a global.

Structs

Marker for an access to shared data which is used for reading.

Marker for an access to shared data which is used for writing but not reading.

Traits

A type flag for shared pointers.