Crate dioxus_shareables
source · [−]Expand description
Crate dioxus-shareables
This crate provides abstractions for global resource sharing in
dioxus similar to fermi, but with a slightly different data
model, and some extensions for shared structures.
The primary interfaces for the crate are Shared, shareable_struct and List
dioxus is still under development; if you’re using the latest nightly version of dioxus
then your Cargo.toml should look something like this:
...
[dependencies]
...
dioxus-shareables = { version = "0.2.4", features = "dixous-git" }
...
[replace]
"dioxus-core:0.2.1" = { git = 'https://github.com/dioxuslabs/dioxus' }
"dioxus-hooks:0.2.1" = { git = 'https://github.com/dioxuslabs/dioxus' }
Re-exports
Modules
Macros
Create a
struct definition for a global.Get actions on a struct.
Structs
Marker for an access to shared data which is used for reading.
Marker for an access to shared data which is used for writing but not reading.