Struct dioxus_shareables::shared::Shareable
source · [−]pub struct Shareable<T>(_);Expand description
The storage type for a shared global.
This is generally not used directly, but it is the type of a static declared with the
shareable! macro, and can be used to construct more complicated shared
types.
Implementations