pub trait InitType: InitType { }
A type flag for fields in shared structures.
This trait is implemented for W, RW, and [()], so it is either a Flag or the unit type (which is used to indicate a field is not initialized.)
W
RW
()